@@ -27,7 +27,7 @@ FOMC_test <- data.frame(
 
 test_that("Fitting with large parameter correlation gives warnings", {
 
-  skip("Skip test for warnings triggered by large parameter correlation as it failed on r-forge")
+  #skip("Skip test for warnings triggered by large parameter correlation as it failed on r-forge")
 
   # When fitting from the maximum, the Port algorithm does not converge (with
   # default settings)
